%   Simulating a RSOM on an Artificial Time Series
%   Network type: SOMSD, training for 10000 epochs
%
%   ---------------------------------------------------------
%   Amir Reza Saffari Azar Alamdari
%   http://www.ymer.org/main.htm , amir@ymer.org
%   ---------------------------------------------------------

close all
clear all
clc

%% Initializing
CurVersion  = 'V02';
SimName     = 'RSOMSim';

ResultDir   = ['Results/' , SimName , CurVersion , '/'];
ResultFile  = [SimName , CurVersion];

if exist(ResultDir) ~= 7
    
    mkdir(ResultDir)
    
end

addpath(genpath(cd))

DataVersion = 'V01';
DataName    = 'Artif';

load(['Results/' , DataName , DataVersion , '/' , DataName , DataVersion])

disp([ResultFile , '...'])

%% Creating RSOM
RSOMSize    = [6 , 6];

Net = CreateNetRSOM(1 , RSOMSize , 'RSOMType' , 'SOMSD' , 'RSOMNeiFunP' , 2 , 'RSOMUnSLFun' , 'RSOMHebbV01' , 'ShowMessages' , 0);

%% Training RSOM
Epoch       = 1;
MaxEpoch    = 100;

Net.State.MaxEpoch  = MaxEpoch;

tic

while Epoch <= MaxEpoch
    
    Net.State.Epoch = Epoch;
       
    disp(['Epoch: ' , num2str(Epoch)])
    
    I   = DataTrain;
        
    Net = SimNetRSOM(Net , I);
    
    Net.State.RSOMState = zeros(size(Net.State.RSOMState , 1) , 1);
    
    Epoch   = Epoch + 1;
end

toc

%% Simulating
Net.Learn.RSOMUnSLFun   = 'None';

disp('Simulating time series ...')

I   = [DataTrain DataTest];

Net = SimNetRSOM(Net , I);

%% Saving
MatlabVer   = version;

if MatlabVer(1) == '7'
    save([ResultDir , ResultFile] , 'Net' , '-V6')
else
    save([ResultDir , ResultFile] , 'Net')
end

disp('Done.')